@@ -3,25 +3,53 @@ OC.L10N.register(
     {
     "Unexpected error sending email. Please contact your administrator." : "Prodúxose un error inesperáu al unviar el mensaxe. Ponte en contautu col alministrador.",
     "Hello," : "Hola,",
+    "Open »%s«" : "Abrir «%s»",
     "Upcoming events" : "Eventos próximos",
     "More events" : "Más eventos",
     "Calendar" : "Calendariu",
     "%1$s - %2$s" : "%1$s - %2$s",
+    "Confirm" : "Confirmar",
     "Date:" : "Data:",
+    "Next week" : "La selmana que vien",
+    "Event" : "Eventu",
     "Today" : "Güei",
+    "Day" : "Día",
+    "Week" : "Selmana",
+    "Month" : "Mes",
     "Year" : "Añu",
+    "Preview" : "Previsualizar",
+    "Copy link" : "Copiar l'enllaz",
     "Edit" : "Editar",
     "Delete" : "Desaniciar",
+    "Untitled calendar" : "Calendariu ensin títulu",
+    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Va dexar de compartise'l calendariu en {countdown} segundu","Va dexar de compartise'l calendariu en {countdown} segundos"],
+    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Va desaniciase'l calendariu en {countdown} segundu","Va desaniciase'l calendariu en {countdown} segundos"],
+    "Export" : "Esportar",
+    "Calendar link copied to clipboard." : "L'enllaz del calendariu copióse nel cartafueyu.",
+    "Calendar link could not be copied to clipboard." : "L'enllaz del calendariu nun se pudo copiar nel cartafueyu.",
     "Trash bin" : "Papelera",
     "Name" : "Nome",
+    "Deleted" : "Desanicióse",
+    "Restore" : "Restaurar",
+    "Delete permanently" : "Desaniciar permanentemente",
+    "Untitled item" : "Elementu ensin nome",
+    "Could not restore calendar or event" : "Nun se pudo restaurar el calendariu o l'eventu",
     "Internal link" : "Enllaz internu",
     "A private link that can be used with external clients" : "Un enllaz priváu que se pue usar con veceros esternos",
+    "Share link" : "Compartir l'enllaz",
+    "Copy public link" : "Copiar l'enllaz públicu",
+    "Unshare with {displayName}" : "Dexar de compartir con {displayName}",
     "An error occurred while unsharing the calendar." : "Prodúxose un error mentanto se dexaba de compartir el calendariu.",
+    "Share with users or groups" : "Compartir con usuarios o grupos",
+    "No users or groups" : "Nun hai nengún usuariu nin grupu",
     "Save" : "Guardar",
+    "Failed to save calendar name and color" : "Nun se pue guardar el nome y el color del calendariu",
     "Cancel" : "Encaboxar",
     "Navigation" : "Navegación",
     "Actions" : "Aiciones",
     "Editor" : "Editor",
+    "Close editor" : "Zarrar l'editor",
+    "Failed to save default calendar" : "Nun se pue guardar el calendariu predetermináu",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minutu","{duration} minutos"],
     "0 minutes" : "0 minutos",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} hores"],
@@ -29,7 +57,9 @@ OC.L10N.register(
     "_{duration} week_::_{duration} weeks_" : ["{duration} selmana","{duration} selmanes"],
     "_{duration} month_::_{duration} months_" : ["{duration} mes","{duration} meses"],
     "_{duration} year_::_{duration} years_" : ["{duration} añu","{duration} años"],
+    "Location" : "Llocalización",
     "Description" : "Descripción",
+    "Visibility" : "Visibilidá",
     "Duration" : "Duración",
     "Add" : "Amestar",
     "Monday" : "Llunes",
@@ -39,14 +69,27 @@ OC.L10N.register(
     "Friday" : "Vienres",
     "Saturday" : "Sábadu",
     "Sunday" : "Domingu",
+    "Update" : "Anovar",
+    "Your email address" : "La to direición de corréu electrónicu",
     "Notification" : "Avisu",
+    "Email" : "Corréu electrónicu",
     "_second_::_seconds_" : ["segundu","segundos"],
     "_minute_::_minutes_" : ["minutu","minutos"],
     "_hour_::_hours_" : ["hora","hores"],
     "_day_::_days_" : ["día","díes"],
     "_week_::_weeks_" : ["selmana","selmanes"],
+    "Delete file" : "Desaniciar el ficheru",
+    "Done" : "Fecho",
+    "Out of office" : "Fuera de la oficina",
     "Accept" : "Aceptar",
     "Decline" : "Refugar",
+    "Failed to accept the invitation." : "Nun se pue aceptar la invitación",
+    "Failed to decline the invitation." : "Nun se pue refugar la invitación",
+    "Attendees" : "Asistentes",
+    "Remove group" : "Quitar el grupu",
+    "All day" : "Tol día",
+    "Repeat" : "Repitir",
+    "never" : "enxamás",
     "_month_::_months_" : ["mes","meses"],
     "_year_::_years_" : ["añu","años"],
     "Suggestions" : "Suxerencies",
@@ -55,51 +98,35 @@ OC.L10N.register(
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asientu","{seatingCapacity} asientos"],
     "Projector" : "Proyeutor",
     "Whiteboard" : "Pizarra",
-    "More" : "Más",
     "Please enter a valid date" : "Introduz una data válida",
+    "Global" : "Global",
     "Time:" : "Hora:",
+    "Personal" : "Personal",
     "[Today]" : "[Güei]",
     "[Tomorrow]" : "[Mañana]",
     "[Yesterday]" : "[Ayeri]",
     "Event does not exist" : "L'eventu nun esiste",
     "Details" : "Detalles",
+    "Invite" : "Convidar",
     "Resources" : "Recursos",
+    "Close" : "Zarrar",
+    "Untitled event" : "Eventu ensin títulu",
+    "Miscellaneous" : "Miscelanea",
     "Daily" : "Caldía",
     "Weekly" : "Selmanalmente",
     "_Every %n day_::_Every %n days_" : ["Cada %n día","Cada %n díes"],
     "_Every %n week_::_Every %n weeks_" : ["Cada %n selmana","Cada %n selmanes"],
     "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n meses"],
     "_Every %n year_::_Every %n years_" : ["Cada %n añu","Cada %n años"],
+    "Untitled task" : "Xera ensin títulu",
     "%n more" : "%n más",
+    "Failed to save event" : "Nun se pue guardar l'eventu",
+    "When shared show full event" : "Cuando se comparta amosar l'eventu completu",
+    "When shared hide this event" : "Cuando se comparta anubrir l'eventu",
     "Status" : "Estáu",
-    "Meditation" : "Meditación",
-    "Dog" : "Perru",
-    "Concert" : "Conciertu",
-    "Festival" : "Festival",
-    "Theatre" : "Teatru",
-    "Presentation" : "Presentación",
-    "Election" : "Eleición",
-    "Barbecue" : "Barbacoa",
-    "Garden" : "Xardín",
-    "Movie" : "Filme",
-    "Cinema" : "Cine",
-    "Graduation" : "Graduación",
-    "Inspection" : "Inspeición",
-    "Soccer" : "Fútbol",
-    "Basketball" : "Baloncestu",
-    "Museum" : "Muséu",
-    "Pilates" : "Pilates",
-    "Park" : "Parque",
-    "Hospital" : "Hospital",
-    "Sports" : "Deportes",
-    "Exercise" : "Exerciciu",
-    "Gym" : "Ximnasiu",
-    "Written test" : "Prueba escrita",
-    "Oral test" : "Prueba oral",
-    "Fireworks" : "Voladores",
-    "Marathon" : "Maratón",
-    "Seminar" : "Seminariu",
-    "Celebration" : "Celebración",
-    "Golf" : "Golf"
+    "Categories" : "Categories",
+    "Error while sharing file" : "Hebo un error mentanto se compartía'l ficheru",
+    "An error occurred, unable to delete the calendar." : "Prodúxose un error, nun ye posible desaniciar el calendariu",
+    "User not found" : "Nun s'atopó l'usuariu"
 },
 "nplurals=2; plural=(n != 1);");
