@@ -10,8 +10,10 @@ OC.L10N.register(
     "Name" : "Ime",
     "Deleted" : "Obrisano",
     "Delete permanently" : "Obriši zauvek",
+    "Copy internal link" : "Kopiraj internu vezu",
     "Share link" : "Veza deljenja",
     "can edit" : "može da menja",
+    "Save" : "Save",
     "Filename" : "Ime fajla",
     "Cancel" : "Cancel",
     "List view" : "Prikaz liste",
@@ -24,18 +26,15 @@ OC.L10N.register(
     "Friday" : "Petak",
     "Saturday" : "Subota",
     "Sunday" : "Nedelja",
-    "Save" : "Save",
     "Update" : "Ažuriraj",
     "Email" : "email",
+    "Done" : "Gotovo",
     "Unknown" : "Nepoznato",
     "never" : "never",
-    "More" : "More",
     "Details" : "Detalji",
     "Close" : "Zatvori",
     "Daily" : "дневно",
     "Weekly" : "недељно",
-    "Other" : "Ostali",
-    "Movie" : "Film",
-    "Mail" : "Pošta"
+    "Other" : "Ostali"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
