@@ -31,9 +31,9 @@ class ServiceException extends Exception {
 	private $httpCode;
 
 	public function __construct($message = "",
-								$code = 0,
-								Throwable $previous = null,
-								int $httpCode = null) {
+		$code = 0,
+		?Throwable $previous = null,
+		?int $httpCode = null) {
 		parent::__construct($message, $code, $previous);
 		$this->httpCode = $httpCode;
 	}
