@@ -146,14 +146,14 @@ class MailService {
 		try {
 			$failed = $this->mailer->send($message);
 			if (count($failed) > 0) {
-				$this->logger->warning('Mail delivery failed for some recipients.');
+				$this->logger->warning('Mail delivery failed for some recipients.', ['app' => 'calendar-appointments']);
 				foreach ($failed as $fail) {
-					$this->logger->debug('Failed to deliver email to ' . $fail);
+					$this->logger->debug('Failed to deliver email to ' . $fail, ['app' => 'calendar-appointments']);
 				}
 				throw new ServiceException('Could not send mail for recipient(s) ' . implode(', ', $failed));
 			}
 		} catch (Exception $ex) {
-			$this->logger->error($ex->getMessage(), ['exception' => $ex]);
+			$this->logger->error($ex->getMessage(), ['exception' => $ex, 'app' => 'calendar-appointments']);
 			throw new ServiceException('Could not send mail: ' . $ex->getMessage(), $ex->getCode(), $ex);
 		}
 	}
@@ -215,14 +215,14 @@ class MailService {
 		try {
 			$failed = $this->mailer->send($message);
 			if (count($failed) > 0) {
-				$this->logger->warning('Mail delivery failed for some recipients.');
+				$this->logger->warning('Mail delivery failed for some recipients.', ['app' => 'calendar-appointments']);
 				foreach ($failed as $fail) {
-					$this->logger->debug('Failed to deliver email to ' . $fail);
+					$this->logger->debug('Failed to deliver email to ' . $fail, ['app' => 'calendar-appointments']);
 				}
 				throw new ServiceException('Could not send mail for recipient(s) ' . implode(', ', $failed));
 			}
 		} catch (Exception $ex) {
-			$this->logger->error($ex->getMessage(), ['exception' => $ex]);
+			$this->logger->error($ex->getMessage(), ['exception' => $ex, 'app' => 'calendar-appointments']);
 			throw new ServiceException('Could not send mail: ' . $ex->getMessage(), $ex->getCode(), $ex);
 		}
 	}
@@ -284,12 +284,12 @@ class MailService {
 		if ($toEmail === null) {
 			throw new ServiceException('Organizer has no email set');
 		}
-		$fromName = $user->getDisplayName();
+		$toName = $user->getDisplayName();
 
 		$sys = $this->getSysEmail();
 		$message = $this->mailer->createMessage()
-			->setFrom([$sys => $fromName])
-			->setTo([$toEmail => $booking->getDisplayName()]);
+			->setFrom([$sys => $booking->getDisplayName()])
+			->setTo([$toEmail => $toName]);
 
 
 		$template = $this->mailer->createEMailTemplate('calendar.confirmOrganizer');
@@ -320,14 +320,14 @@ class MailService {
 		try {
 			$failed = $this->mailer->send($message);
 			if (count($failed) > 0) {
-				$this->logger->warning('Mail delivery failed for some recipients.');
+				$this->logger->warning('Mail delivery failed for some recipients.', ['app' => 'calendar-appointments']);
 				foreach ($failed as $fail) {
-					$this->logger->debug('Failed to deliver email to ' . $fail);
+					$this->logger->debug('Failed to deliver email to ' . $fail, ['app' => 'calendar-appointments']);
 				}
 				throw new ServiceException('Could not send mail for recipient(s) ' . implode(', ', $failed));
 			}
 		} catch (Exception $ex) {
-			$this->logger->error('Could not send appointment organizer email: ' . $ex->getMessage(), ['exception' => $ex]);
+			$this->logger->error('Could not send appointment organizer email: ' . $ex->getMessage(), ['exception' => $ex, 'app' => 'calendar-appointments']);
 			throw new ServiceException('Could not send mail: ' . $ex->getMessage(), $ex->getCode(), $ex);
 		}
 	}
